pub struct CollectingReporter {
pub diagnostics: Vec<Diagnostic>,
}Expand description
A simple in-memory reporter useful for testing.
Fields
diagnostics: Vec<Diagnostic>Trait Implementations
Sourceimpl Debug for CollectingReporter
impl Debug for CollectingReporter
Sourceimpl Default for CollectingReporter
impl Default for CollectingReporter
Sourcefn default() -> CollectingReporter
fn default() -> CollectingReporter
Returns the “default value” for a type. Read more
Sourceimpl Reporter for CollectingReporter
impl Reporter for CollectingReporter
Sourcefn report(&mut self, diagnostic: &Diagnostic, _source: &str, _filename: &str)
fn report(&mut self, diagnostic: &Diagnostic, _source: &str, _filename: &str)
Emit a single diagnostic against the provided source text.
Sourcefn has_errors(&self) -> bool
fn has_errors(&self) -> bool
Returns
true if at least one error has been reported.Auto Trait Implementations
impl Freeze for CollectingReporter
impl RefUnwindSafe for CollectingReporter
impl Send for CollectingReporter
impl Sync for CollectingReporter
impl Unpin for CollectingReporter
impl UnsafeUnpin for CollectingReporter
impl UnwindSafe for CollectingReporter