pub trait Reporter {
// Required methods
fn report(&mut self, diagnostic: &Diagnostic, source: &str, filename: &str);
fn has_errors(&self) -> bool;
}Expand description
Trait for sinks that receive and display diagnostics.
Required Methods
Sourcefn report(&mut self, diagnostic: &Diagnostic, source: &str, filename: &str)
fn report(&mut self, diagnostic: &Diagnostic, source: &str, filename: &str)
Emit a single diagnostic against the provided source text.
Sourcefn has_errors(&self) -> bool
fn has_errors(&self) -> bool
Returns true if at least one error has been reported.